@@ -21,6 +21,7 @@ from .utils import (
     is_einops_available,
     is_fastdeploy_available,
     is_inflect_available,
+    is_invisible_watermark_available,
     is_k_diffusion_available,
     is_k_diffusion_version,
     is_librosa_available,
@@ -29,13 +30,15 @@ from .utils import (
     is_paddle_version,
     is_paddlenlp_available,
     is_paddlenlp_version,
+    is_paddlesde_available,
     is_ppxformers_available,
     is_safetensors_available,
     is_scipy_available,
     is_torch_available,
     is_unidecode_available,
     is_visualdl_available,
-    logging, )
+    logging,
+)
 from .version import VERSION as __version__
 
 try:
@@ -53,6 +56,7 @@ except OptionalDependencyNotAvailable:
     from .utils.dummy_paddle_objects import *  # noqa F403
 else:
     from .models import (
+        AsymmetricAutoencoderKL,
         AutoencoderKL,
         ControlNetModel,
         LitEma,
@@ -68,7 +72,8 @@ else:
         UNet2DConditionModel,
         UNet2DModel,
         UNet3DConditionModel,
-        VQModel, )
+        VQModel,
+    )
     from .optimization import (
         get_constant_schedule,
         get_constant_schedule_with_warmup,
@@ -76,9 +81,14 @@ else:
         get_cosine_with_hard_restarts_schedule_with_warmup,
         get_linear_schedule_with_warmup,
         get_polynomial_decay_schedule_with_warmup,
-        get_scheduler, )
+        get_scheduler,
+    )
     from .pipelines import (
         AudioPipelineOutput,
+        AutoPipelineForImage2Image,
+        AutoPipelineForInpainting,
+        AutoPipelineForText2Image,
+        ConsistencyModelPipeline,
         DanceDiffusionPipeline,
         DDIMPipeline,
         DDPMPipeline,
@@ -91,12 +101,17 @@ else:
         PNDMPipeline,
         RePaintPipeline,
         ScoreSdeVePipeline,
-        TextPipelineOutput, )
+        TextPipelineOutput,
+    )
     from .schedulers import (
+        CMStochasticIterativeScheduler,
         DDIMInverseScheduler,
+        DDIMParallelScheduler,
         DDIMScheduler,
+        DDPMParallelScheduler,
         DDPMScheduler,
         DEISMultistepScheduler,
+        DPMSolverMultistepInverseScheduler,
         DPMSolverMultistepScheduler,
         DPMSolverSinglestepScheduler,
         DPMSolverUniDiffuserScheduler,
@@ -113,10 +128,12 @@ else:
         ScoreSdeVeScheduler,
         UnCLIPScheduler,
         UniPCMultistepScheduler,
-        VQDiffusionScheduler, )
+        VQDiffusionScheduler,
+    )
     from .schedulers.preconfig import (
         PreconfigEulerAncestralDiscreteScheduler,
-        PreconfigLMSDiscreteScheduler, )
+        PreconfigLMSDiscreteScheduler,
+    )
     from .training_utils import EMAModel
 
 try:
@@ -127,13 +144,22 @@ except OptionalDependencyNotAvailable:
 else:
     from .schedulers import LMSDiscreteScheduler
 
+try:
+    if not (is_paddle_available() and is_paddlesde_available()):
+        raise OptionalDependencyNotAvailable()
+except OptionalDependencyNotAvailable:
+    from .utils.dummy_paddle_and_paddlesde_objects import *  # noqa F403
+else:
+    from .schedulers import DPMSolverSDEScheduler
+
+
 try:
     if not (is_paddle_available() and is_paddlenlp_available()):
         raise OptionalDependencyNotAvailable()
 except OptionalDependencyNotAvailable:
     from .utils.dummy_paddle_and_paddlenlp_objects import *  # noqa F403
 else:
-    from .pipelines import (
+    from .pipelines import (  # ImageTextPipelineOutput,
         AltDiffusionImg2ImgPipeline,
         AltDiffusionPipeline,
         AudioLDMPipeline,
@@ -144,30 +170,59 @@ else:
         IFInpaintingSuperResolutionPipeline,
         IFPipeline,
         IFSuperResolutionPipeline,
+        KandinskyCombinedPipeline,
+        KandinskyImg2ImgCombinedPipeline,
+        KandinskyImg2ImgPipeline,
+        KandinskyInpaintCombinedPipeline,
+        KandinskyInpaintPipeline,
+        KandinskyPipeline,
+        KandinskyPriorPipeline,
+        KandinskyV22CombinedPipeline,
+        KandinskyV22ControlnetImg2ImgPipeline,
+        KandinskyV22ControlnetPipeline,
+        KandinskyV22Img2ImgCombinedPipeline,
+        KandinskyV22Img2ImgPipeline,
+        KandinskyV22InpaintCombinedPipeline,
+        KandinskyV22InpaintPipeline,
+        KandinskyV22Pipeline,
+        KandinskyV22PriorEmb2EmbPipeline,
+        KandinskyV22PriorPipeline,
         LDMTextToImagePipeline,
-        LVDMUncondPipeline,
         LVDMTextToVideoPipeline,
+        LVDMUncondPipeline,
         PaintByExamplePipeline,
         SemanticStableDiffusionPipeline,
+        ShapEImg2ImgPipeline,
+        ShapEPipeline,
         StableDiffusionAdapterPipeline,
         StableDiffusionAttendAndExcitePipeline,
+        StableDiffusionControlNetImg2ImgPipeline,
+        StableDiffusionControlNetInpaintPipeline,
         StableDiffusionControlNetPipeline,
         StableDiffusionDepth2ImgPipeline,
+        StableDiffusionDiffEditPipeline,
         StableDiffusionImageVariationPipeline,
         StableDiffusionImg2ImgPipeline,
         StableDiffusionInpaintPipeline,
         StableDiffusionInpaintPipelineLegacy,
         StableDiffusionInstructPix2PixPipeline,
         StableDiffusionLatentUpscalePipeline,
+        StableDiffusionLDM3DPipeline,
         StableDiffusionMegaPipeline,
         StableDiffusionModelEditingPipeline,
         StableDiffusionPanoramaPipeline,
+        StableDiffusionParadigmsPipeline,
         StableDiffusionPipeline,
         StableDiffusionPipelineAllinOne,
         StableDiffusionPipelineSafe,
         StableDiffusionPix2PixZeroPipeline,
         StableDiffusionSAGPipeline,
         StableDiffusionUpscalePipeline,
+        StableDiffusionXLControlNetPipeline,
+        StableDiffusionXLImg2ImgPipeline,
+        StableDiffusionXLInpaintPipeline,
+        StableDiffusionXLInstructPix2PixPipeline,
+        StableDiffusionXLPipeline,
         StableUnCLIPImg2ImgPipeline,
         StableUnCLIPPipeline,
         TextToVideoSDPipeline,
@@ -179,13 +234,13 @@ else:
         VersatileDiffusionImageVariationPipeline,
         VersatileDiffusionPipeline,
         VersatileDiffusionTextToImagePipeline,
-        VQDiffusionPipeline, )
+        VideoToVideoSDPipeline,
+        VQDiffusionPipeline,
+    )
     from .pipelines.latent_diffusion.pipeline_latent_diffusion import LDMBertModel
-    from .pipelines.unidiffuser.caption_decoder import CaptionDecoder
 
 try:
-    if not (is_paddle_available() and is_paddlenlp_available() and
-            is_k_diffusion_available()):
+    if not (is_paddle_available() and is_paddlenlp_available() and is_k_diffusion_available()):
         raise OptionalDependencyNotAvailable()
 except OptionalDependencyNotAvailable:
     from .utils.dummy_paddle_and_paddlenlp_and_k_diffusion_objects import *  # noqa F403
@@ -193,8 +248,7 @@ else:
     from .pipelines import StableDiffusionKDiffusionPipeline
 
 try:
-    if not (is_paddle_available() and is_paddlenlp_available() and
-            is_fastdeploy_available()):
+    if not (is_paddle_available() and is_paddlenlp_available() and is_fastdeploy_available()):
         raise OptionalDependencyNotAvailable()
 except OptionalDependencyNotAvailable:
     from .utils.dummy_paddle_and_paddlenlp_and_fastdeploy_objects import *  # noqa F403
@@ -208,7 +262,8 @@ else:
         FastDeployStableDiffusionInpaintPipelineLegacy,
         FastDeployStableDiffusionMegaPipeline,
         FastDeployStableDiffusionPipeline,
-        FastDeployStableDiffusionUpscalePipeline, )
+        FastDeployStableDiffusionUpscalePipeline,
+    )
 
 try:
     if not (is_paddle_available() and is_librosa_available()):
@@ -219,8 +274,7 @@ else:
     from .pipelines import AudioDiffusionPipeline, Mel
 
 try:
-    if not (is_paddle_available() and is_paddlenlp_available() and
-            is_note_seq_available()):
+    if not (is_paddle_available() and is_paddlenlp_available() and is_note_seq_available()):
         raise OptionalDependencyNotAvailable()
 except OptionalDependencyNotAvailable:
     from .utils.dummy_paddle_and_paddlenlp_and_note_seq_objects import *  # noqa F403
@@ -228,8 +282,7 @@ else:
     from .pipelines import SpectrogramDiffusionPipeline
 
 try:
-    if not (is_paddle_available() and is_paddlenlp_available() and
-            is_einops_available()):
+    if not (is_paddle_available() and is_paddlenlp_available() and is_einops_available()):
         raise OptionalDependencyNotAvailable()
 except OptionalDependencyNotAvailable:
     from .utils.dummy_paddle_and_paddlenlp_and_einops_objects import *  # noqa F403
@@ -242,7 +295,11 @@ try:
 except OptionalDependencyNotAvailable:
     from .utils.dummy_paddle_and_einops_objects import *  # noqa F403
 else:
-    from .models import UViTModel
+    from .pipelines.unidiffuser import (
+        UniDiffuserModel,
+        UniDiffuserPipeline,
+        UniDiffuserTextDecoder,
+    )
 
 try:
     if not (is_note_seq_available()):
