@@ -47,8 +47,7 @@ class PreconfigEulerAncestralDiscreteSchedulerOutput(BaseOutput):
 
 
 # Copied from ppdiffusers.schedulers.scheduling_ddpm.betas_for_alpha_bar
-def betas_for_alpha_bar(num_diffusion_timesteps,
-                        max_beta=0.999) -> paddle.Tensor:
+def betas_for_alpha_bar(num_diffusion_timesteps, max_beta=0.999) -> paddle.Tensor:
     """
     Create a beta schedule that discretizes the given alpha_t_bar function, which defines the cumulative product of
     (1-beta) over time from t = [0,1].
@@ -67,7 +66,7 @@ def betas_for_alpha_bar(num_diffusion_timesteps,
     """
 
     def alpha_bar(time_step):
-        return math.cos((time_step + 0.008) / 1.008 * math.pi / 2)**2
+        return math.cos((time_step + 0.008) / 1.008 * math.pi / 2) ** 2
 
     betas = []
     for i in range(num_diffusion_timesteps):
@@ -108,38 +107,34 @@ class PreconfigEulerAncestralDiscreteScheduler(SchedulerMixin, ConfigMixin):
 
     @register_to_config
     def __init__(
-            self,
-            num_train_timesteps: int=1000,
-            beta_start: float=0.0001,
-            beta_end: float=0.02,
-            beta_schedule: str="linear",
-            trained_betas: Optional[Union[np.ndarray, List[float]]]=None,
-            prediction_type: str="epsilon",
-            preconfig: bool=True, ):
+        self,
+        num_train_timesteps: int = 1000,
+        beta_start: float = 0.0001,
+        beta_end: float = 0.02,
+        beta_schedule: str = "linear",
+        trained_betas: Optional[Union[np.ndarray, List[float]]] = None,
+        prediction_type: str = "epsilon",
+        preconfig: bool = True,
+    ):
         if trained_betas is not None:
             self.betas = paddle.to_tensor(trained_betas, dtype=paddle.float32)
         elif beta_schedule == "linear":
-            self.betas = paddle.linspace(
-                beta_start, beta_end, num_train_timesteps, dtype=paddle.float32)
+            self.betas = paddle.linspace(beta_start, beta_end, num_train_timesteps, dtype=paddle.float32)
         elif beta_schedule == "scaled_linear":
             # this schedule is very specific to the latent diffusion model.
-            self.betas = (paddle.linspace(
-                beta_start**0.5,
-                beta_end**0.5,
-                num_train_timesteps,
-                dtype=paddle.float32)**2)
+            self.betas = (
+                paddle.linspace(beta_start**0.5, beta_end**0.5, num_train_timesteps, dtype=paddle.float32) ** 2
+            )
         elif beta_schedule == "squaredcos_cap_v2":
             # Glide cosine schedule
             self.betas = betas_for_alpha_bar(num_train_timesteps)
         else:
-            raise NotImplementedError(
-                f"{beta_schedule} does is not implemented for {self.__class__}")
+            raise NotImplementedError(f"{beta_schedule} does is not implemented for {self.__class__}")
 
         self.alphas = 1.0 - self.betas
         self.alphas_cumprod = paddle.cumprod(self.alphas, 0)
 
-        sigmas = np.array(((1 - self.alphas_cumprod) / self.alphas_cumprod)**
-                          0.5)
+        sigmas = np.array(((1 - self.alphas_cumprod) / self.alphas_cumprod) ** 0.5)
         sigmas = np.concatenate([sigmas[::-1], [0.0]]).astype(np.float32)
         self.sigmas = paddle.to_tensor(sigmas)
 
@@ -148,18 +143,15 @@ class PreconfigEulerAncestralDiscreteScheduler(SchedulerMixin, ConfigMixin):
 
         # setable values
         self.num_inference_steps = None
-        timesteps = np.linspace(
-            0, num_train_timesteps - 1, num_train_timesteps,
-            dtype=float)[::-1].copy()
+        timesteps = np.linspace(0, num_train_timesteps - 1, num_train_timesteps, dtype=float)[::-1].copy()
         self.timesteps = paddle.to_tensor(timesteps, dtype=paddle.float32)
         self.is_scale_input_called = False
         self.preconfig = preconfig
         self.step_index_offset = 0
 
-    def scale_model_input(self,
-                          sample: paddle.Tensor,
-                          timestep: Union[float, paddle.Tensor],
-                          **kwargs) -> paddle.Tensor:
+    def scale_model_input(
+        self, sample: paddle.Tensor, timestep: Union[float, paddle.Tensor], **kwargs
+    ) -> paddle.Tensor:
         """
         Scales the denoising model input by `(sigma**2 + 1) ** 0.5` to match the Euler algorithm.
 
@@ -178,7 +170,7 @@ class PreconfigEulerAncestralDiscreteScheduler(SchedulerMixin, ConfigMixin):
 
         if not self.preconfig:
             sigma = self.sigmas[step_index]
-            sample = sample / ((sigma**2 + 1)**0.5)
+            sample = sample / ((sigma**2 + 1) ** 0.5)
             return sample
         else:
             if step_index > (len(self.latent_scales) - 1):
@@ -196,13 +188,8 @@ class PreconfigEulerAncestralDiscreteScheduler(SchedulerMixin, ConfigMixin):
         self.num_inference_steps = num_inference_steps
         self.step_index_offset = 0
 
-        timesteps = np.linspace(
-            0,
-            self.config.num_train_timesteps - 1,
-            num_inference_steps,
-            dtype=float)[::-1].copy()
-        sigmas = np.array(((1 - self.alphas_cumprod) / self.alphas_cumprod)**
-                          0.5)
+        timesteps = np.linspace(0, self.config.num_train_timesteps - 1, num_inference_steps, dtype=float)[::-1].copy()
+        sigmas = np.array(((1 - self.alphas_cumprod) / self.alphas_cumprod) ** 0.5)
         sigmas = np.interp(timesteps, np.arange(0, len(sigmas)), sigmas)
         sigmas = np.concatenate([sigmas, [0.0]]).astype(np.float32)
         self.sigmas = paddle.to_tensor(sigmas)
@@ -213,22 +200,21 @@ class PreconfigEulerAncestralDiscreteScheduler(SchedulerMixin, ConfigMixin):
             for step_index_i in range(len(self.timesteps)):
                 sigma_from = self.sigmas[step_index_i]
                 sigma_to = self.sigmas[step_index_i + 1]
-                sigma_up = (sigma_to**2 * (sigma_from**2 - sigma_to**2) /
-                            sigma_from**2)**0.5
-                sigma_down = (sigma_to**2 - sigma_up**2)**0.5
+                sigma_up = (sigma_to**2 * (sigma_from**2 - sigma_to**2) / sigma_from**2) ** 0.5
+                sigma_down = (sigma_to**2 - sigma_up**2) ** 0.5
                 self.sigma_up.append(sigma_up)
                 self.sigma_down.append(sigma_down)
-            self.latent_scales = 1 / ((self.sigmas**2 + 1)**0.5)
+            self.latent_scales = 1 / ((self.sigmas**2 + 1) ** 0.5)
 
-    def step(self,
-             model_output: paddle.Tensor,
-             timestep: Union[float, paddle.Tensor],
-             sample: paddle.Tensor,
-             generator: Optional[Union[paddle.Generator, List[
-                 paddle.Generator]]]=None,
-             return_dict: bool=True,
-             **kwargs) -> Union[PreconfigEulerAncestralDiscreteSchedulerOutput,
-                                Tuple]:
+    def step(
+        self,
+        model_output: paddle.Tensor,
+        timestep: Union[float, paddle.Tensor],
+        sample: paddle.Tensor,
+        generator: Optional[Union[paddle.Generator, List[paddle.Generator]]] = None,
+        return_dict: bool = True,
+        **kwargs
+    ) -> Union[PreconfigEulerAncestralDiscreteSchedulerOutput, Tuple]:
         """
         Predict the sample at the previous timestep by reversing the SDE. Core function to propagate the diffusion
         process from the learned model outputs (most often the predicted noise).
@@ -250,7 +236,8 @@ class PreconfigEulerAncestralDiscreteScheduler(SchedulerMixin, ConfigMixin):
         if not self.is_scale_input_called:
             logger.warning(
                 "The `scale_model_input` function should be called before `step` to ensure correct denoising. "
-                "See `StableDiffusionPipeline` for a usage example.")
+                "See `StableDiffusionPipeline` for a usage example."
+            )
         if kwargs.get("return_pred_original_sample") is not None:
             return_pred_original_sample = kwargs["return_pred_original_sample"]
         else:
@@ -269,11 +256,9 @@ class PreconfigEulerAncestralDiscreteScheduler(SchedulerMixin, ConfigMixin):
                 pred_original_sample = sample - sigma * model_output
             elif self.config.prediction_type == "v_prediction":
                 # * c_out + input * c_skip
-                pred_original_sample = model_output * (-sigma / (
-                    sigma**2 + 1)**0.5) + (sample / (sigma**2 + 1))
+                pred_original_sample = model_output * (-sigma / (sigma**2 + 1) ** 0.5) + (sample / (sigma**2 + 1))
             elif self.config.prediction_type == "sample":
-                raise NotImplementedError(
-                    "prediction_type not implemented yet: sample")
+                raise NotImplementedError("prediction_type not implemented yet: sample")
             else:
                 raise ValueError(
                     f"prediction_type given as {self.config.prediction_type} must be one of `epsilon`, or `v_prediction`"
@@ -282,38 +267,37 @@ class PreconfigEulerAncestralDiscreteScheduler(SchedulerMixin, ConfigMixin):
         if not self.preconfig:
             sigma_from = self.sigmas[step_index]
             sigma_to = self.sigmas[step_index + 1]
-            sigma_up = (sigma_to**2 * (sigma_from**2 - sigma_to**2) / sigma_from
-                        **2)**0.5
-            sigma_down = (sigma_to**2 - sigma_up**2)**0.5
+            sigma_up = (sigma_to**2 * (sigma_from**2 - sigma_to**2) / sigma_from**2) ** 0.5
+            sigma_down = (sigma_to**2 - sigma_up**2) ** 0.5
         else:
             sigma_up = self.sigma_up[step_index]
             sigma_down = self.sigma_down[step_index]
         # 2. Convert to an ODE derivative
         dt = sigma_down - sigma
         prev_sample = sample + derivative * dt
-        noise = randn_tensor(
-            model_output.shape, dtype=model_output.dtype, generator=generator)
+        noise = randn_tensor(model_output.shape, dtype=model_output.dtype, generator=generator)
         prev_sample = prev_sample + noise * sigma_up
         if not return_dict:
             if not return_pred_original_sample:
-                return (prev_sample, )
+                return (prev_sample,)
             else:
                 return (prev_sample, pred_original_sample)
 
         return PreconfigEulerAncestralDiscreteSchedulerOutput(
-            prev_sample=prev_sample, pred_original_sample=pred_original_sample)
+            prev_sample=prev_sample, pred_original_sample=pred_original_sample
+        )
 
     def add_noise(
-            self,
-            original_samples: paddle.Tensor,
-            noise: paddle.Tensor,
-            timesteps: paddle.Tensor, ) -> paddle.Tensor:
+        self,
+        original_samples: paddle.Tensor,
+        noise: paddle.Tensor,
+        timesteps: paddle.Tensor,
+    ) -> paddle.Tensor:
         # Make sure sigmas and timesteps have the same dtype as original_samples
         self.sigmas = self.sigmas.cast(original_samples.dtype)
 
         schedule_timesteps = self.timesteps
-        step_indices = [(schedule_timesteps == t).nonzero().item()
-                        for t in timesteps]
+        step_indices = [(schedule_timesteps == t).nonzero().item() for t in timesteps]
 
         sigma = self.sigmas[step_indices].flatten()
         while len(sigma.shape) < len(original_samples.shape):
