@@ -26,6 +26,20 @@ from packaging.version import Version, parse
 
 from . import logging
 
+
+def str2bool(v):
+    if isinstance(v, bool):
+        return v
+    if not isinstance(v, str):
+        v = str(v)
+    if v.lower() in ("yes", "true", "t", "y", "1"):
+        return True
+    elif v.lower() in ("no", "false", "f", "n", "0"):
+        return False
+    else:
+        raise ValueError("Not supported value: {}".format(v))
+
+
 # The package importlib_metadata is in a different place, depending on the python version.
 if sys.version_info < (3, 8):
     import importlib_metadata
@@ -40,14 +54,7 @@ ENV_VARS_TRUE_AND_AUTO_VALUES = ENV_VARS_TRUE_VALUES.union({"AUTO"})
 USE_PADDLE = os.environ.get("USE_PADDLE", "AUTO").upper()
 USE_SAFETENSORS = os.environ.get("USE_SAFETENSORS", "AUTO").upper()
 
-STR_OPERATION_TO_FUNC = {
-    ">": op.gt,
-    ">=": op.ge,
-    "==": op.eq,
-    "!=": op.ne,
-    "<=": op.le,
-    "<": op.lt
-}
+STR_OPERATION_TO_FUNC = {">": op.gt, ">=": op.ge, "==": op.eq, "!=": op.ne, "<=": op.le, "<": op.lt}
 
 _paddle_version = "N/A"
 if USE_PADDLE in ENV_VARS_TRUE_AND_AUTO_VALUES:
@@ -65,7 +72,8 @@ if USE_PADDLE in ENV_VARS_TRUE_AND_AUTO_VALUES:
         if _paddle_available:
             try:
                 from paddle.incubate.nn.memory_efficient_attention import (  # noqa
-                    memory_efficient_attention, )
+                    memory_efficient_attention,
+                )
 
                 _ppxformers_available = True
             except ImportError:
@@ -90,8 +98,7 @@ if USE_SAFETENSORS in ENV_VARS_TRUE_AND_AUTO_VALUES:
     if _safetensors_available:
         try:
             _safetensors_version = importlib_metadata.version("safetensors")
-            logger.info(
-                f"Safetensors version {_safetensors_version} available.")
+            logger.info(f"Safetensors version {_safetensors_version} available.")
         except importlib_metadata.PackageNotFoundError:
             _safetensors_available = False
 else:
@@ -101,8 +108,7 @@ else:
 _transformers_available = importlib.util.find_spec("transformers") is not None
 try:
     _transformers_version = importlib_metadata.version("transformers")
-    logger.debug(
-        f"Successfully imported transformers version {_transformers_version}")
+    logger.debug(f"Successfully imported transformers version {_transformers_version}")
 except importlib_metadata.PackageNotFoundError:
     _transformers_available = False
 
@@ -116,8 +122,7 @@ except importlib_metadata.PackageNotFoundError:
 _unidecode_available = importlib.util.find_spec("unidecode") is not None
 try:
     _unidecode_version = importlib_metadata.version("unidecode")
-    logger.debug(
-        f"Successfully imported unidecode version {_unidecode_version}")
+    logger.debug(f"Successfully imported unidecode version {_unidecode_version}")
 except importlib_metadata.PackageNotFoundError:
     _unidecode_available = False
 
@@ -134,14 +139,12 @@ if _fastdeploy_available:
             pass
     _fastdeploy_available = _fastdeploy_version != "N/A"
     if _fastdeploy_available:
-        logger.debug(
-            f"Successfully imported fastdeploy version {_fastdeploy_version}")
+        logger.debug(f"Successfully imported fastdeploy version {_fastdeploy_version}")
 
 _paddlenlp_available = importlib.util.find_spec("paddlenlp") is not None
 try:
     _paddlenlp_version = importlib_metadata.version("paddlenlp")
-    logger.debug(
-        f"Successfully imported paddlenlp version {_paddlenlp_version}")
+    logger.debug(f"Successfully imported paddlenlp version {_paddlenlp_version}")
 except importlib_metadata.PackageNotFoundError:
     _paddlenlp_available = False
 
@@ -152,7 +155,8 @@ try:
         "opencv-python",
         "opencv-contrib-python",
         "opencv-python-headless",
-        "opencv-contrib-python-headless", )
+        "opencv-contrib-python-headless",
+    )
     _opencv_version = None
     for pkg in candidates:
         try:
@@ -183,8 +187,7 @@ except importlib_metadata.PackageNotFoundError:
 _k_diffusion_available = importlib.util.find_spec("k_diffusion") is not None
 try:
     _k_diffusion_version = importlib_metadata.version("k_diffusion")
-    logger.debug(
-        f"Successfully imported k-diffusion version {_k_diffusion_version}")
+    logger.debug(f"Successfully imported k-diffusion version {_k_diffusion_version}")
 except importlib_metadata.PackageNotFoundError:
     _k_diffusion_available = False
 
@@ -205,16 +208,14 @@ except importlib_metadata.PackageNotFoundError:
 _omegaconf_available = importlib.util.find_spec("omegaconf") is not None
 try:
     _omegaconf_version = importlib_metadata.version("omegaconf")
-    logger.debug(
-        f"Successfully imported omegaconf version {_omegaconf_version}")
+    logger.debug(f"Successfully imported omegaconf version {_omegaconf_version}")
 except importlib_metadata.PackageNotFoundError:
     _omegaconf_available = False
 
 _tensorboard_available = importlib.util.find_spec("tensorboard")
 try:
     _tensorboard_version = importlib_metadata.version("tensorboard")
-    logger.debug(
-        f"Successfully imported tensorboard version {_tensorboard_version}")
+    logger.debug(f"Successfully imported tensorboard version {_tensorboard_version}")
 except importlib_metadata.PackageNotFoundError:
     _tensorboard_available = False
 
@@ -232,8 +233,7 @@ try:
         import einops.layers.paddle
 
         einops.layers.paddle
-        logger.debug(
-            f"Successfully imported einops version {einops.__version__}")
+        logger.debug(f"Successfully imported einops version {einops.__version__}")
     except ImportError:
         _einops_available = False
 except importlib_metadata.PackageNotFoundError:
@@ -261,6 +261,20 @@ try:
 except importlib_metadata.PackageNotFoundError:
     _bs4_available = False
 
+_paddlesde_available = importlib.util.find_spec("paddlesde") is not None
+try:
+    _paddlesde_version = importlib_metadata.version("paddlesde")
+    logger.debug(f"Successfully imported paddlesde version {_paddlesde_version}")
+except importlib_metadata.PackageNotFoundError:
+    _paddlesde_available = False
+
+_invisible_watermark_available = importlib.util.find_spec("imwatermark") is not None
+try:
+    _invisible_watermark_version = importlib_metadata.version("invisible-watermark")
+    logger.debug(f"Successfully imported invisible-watermark version {_invisible_watermark_version}")
+except importlib_metadata.PackageNotFoundError:
+    _invisible_watermark_available = False
+
 
 def is_paddle_available():
     return _paddle_available
@@ -279,7 +293,11 @@ def is_fastdeploy_available():
 
 
 def is_ppxformers_available():
-    return _ppxformers_available
+    USE_PPXFORMERS = str2bool(os.getenv("USE_PPXFORMERS", True))
+    if USE_PPXFORMERS:
+        return _ppxformers_available
+    else:
+        False
 
 
 def is_torch_available():
@@ -350,6 +368,14 @@ def is_bs4_available():
     return _bs4_available
 
 
+def is_paddlesde_available():
+    return _paddlesde_available
+
+
+def is_invisible_watermark_available():
+    return _invisible_watermark_available
+
+
 # docstyle-ignore
 FASTDEPLOY_IMPORT_ERROR = """
 {0} requires the fastdeploy library but it was not found in your environment. You can install it with pip: `pip install
@@ -482,27 +508,41 @@ installation section: https://github.com/rspeer/python-ftfy/tree/master#installi
 that match your environment. Please note that you may need to restart your runtime after installation.
 """
 
-BACKENDS_MAPPING = OrderedDict([
-    ("bs4", (is_bs4_available, BS4_IMPORT_ERROR)),
-    ("fastdeploy", (is_fastdeploy_available, FASTDEPLOY_IMPORT_ERROR)),
-    ("paddle", (is_paddle_available, PADDLE_IMPORT_ERROR)),
-    ("paddlenlp", (is_paddlenlp_available, PADDLENLP_IMPORT_ERROR)),
-    ("visualdl", (is_visualdl_available, VISUALDL_IMPORT_ERROR)),
-    ("inflect", (is_inflect_available, INFLECT_IMPORT_ERROR)),
-    ("opencv", (is_opencv_available, OPENCV_IMPORT_ERROR)),
-    ("scipy", (is_scipy_available, SCIPY_IMPORT_ERROR)),
-    ("torch", (is_torch_available, PYTORCH_IMPORT_ERROR)),
-    ("unidecode", (is_unidecode_available, UNIDECODE_IMPORT_ERROR)),
-    ("librosa", (is_librosa_available, LIBROSA_IMPORT_ERROR)),
-    ("k_diffusion", (is_k_diffusion_available, K_DIFFUSION_IMPORT_ERROR)),
-    ("wandb", (is_wandb_available, WANDB_IMPORT_ERROR)),
-    ("omegaconf", (is_omegaconf_available, OMEGACONF_IMPORT_ERROR)),
-    ("tensorboard", (is_tensorboard_available, TENSORBOARD_IMPORT_ERROR)),
-    ("einops", (is_einops_available, EINOPS_IMPORT_ERROR)),
-    ("note_seq", (is_note_seq_available, NOTE_SEQ_IMPORT_ERROR)),
-    ("compel", (is_compel_available, COMPEL_IMPORT_ERROR)),
-    ("ftfy", (is_ftfy_available, FTFY_IMPORT_ERROR)),
-])
+# docstyle-ignore
+PADDLESDE_IMPORT_ERROR = """
+{0} requires the paddlesde library but it was not found in your environment. You can install it with pip: `pip install paddlesde`
+"""
+
+# docstyle-ignore
+INVISIBLE_WATERMARK_IMPORT_ERROR = """
+{0} requires the invisible-watermark library but it was not found in your environment. You can install it with pip: `pip install invisible-watermark>=0.2.0`
+"""
+
+BACKENDS_MAPPING = OrderedDict(
+    [
+        ("bs4", (is_bs4_available, BS4_IMPORT_ERROR)),
+        ("fastdeploy", (is_fastdeploy_available, FASTDEPLOY_IMPORT_ERROR)),
+        ("paddle", (is_paddle_available, PADDLE_IMPORT_ERROR)),
+        ("paddlenlp", (is_paddlenlp_available, PADDLENLP_IMPORT_ERROR)),
+        ("visualdl", (is_visualdl_available, VISUALDL_IMPORT_ERROR)),
+        ("inflect", (is_inflect_available, INFLECT_IMPORT_ERROR)),
+        ("opencv", (is_opencv_available, OPENCV_IMPORT_ERROR)),
+        ("scipy", (is_scipy_available, SCIPY_IMPORT_ERROR)),
+        ("torch", (is_torch_available, PYTORCH_IMPORT_ERROR)),
+        ("unidecode", (is_unidecode_available, UNIDECODE_IMPORT_ERROR)),
+        ("librosa", (is_librosa_available, LIBROSA_IMPORT_ERROR)),
+        ("k_diffusion", (is_k_diffusion_available, K_DIFFUSION_IMPORT_ERROR)),
+        ("wandb", (is_wandb_available, WANDB_IMPORT_ERROR)),
+        ("omegaconf", (is_omegaconf_available, OMEGACONF_IMPORT_ERROR)),
+        ("tensorboard", (is_tensorboard_available, TENSORBOARD_IMPORT_ERROR)),
+        ("einops", (is_einops_available, EINOPS_IMPORT_ERROR)),
+        ("note_seq", (is_note_seq_available, NOTE_SEQ_IMPORT_ERROR)),
+        ("compel", (is_compel_available, COMPEL_IMPORT_ERROR)),
+        ("ftfy", (is_ftfy_available, FTFY_IMPORT_ERROR)),
+        ("paddlesde", (is_paddlesde_available, PADDLESDE_IMPORT_ERROR)),
+        ("invisible_watermark", (is_invisible_watermark_available, INVISIBLE_WATERMARK_IMPORT_ERROR)),
+    ]
+)
 
 
 def requires_backends(obj, backends):
@@ -516,26 +556,24 @@ def requires_backends(obj, backends):
         raise ImportError("".join(failed))
 
     if name in [
-            "VersatileDiffusionTextToImagePipeline",
-            "VersatileDiffusionPipeline",
-            "VersatileDiffusionDualGuidedPipeline",
-            "StableDiffusionImageVariationPipeline",
-            "UnCLIPPipeline",
+        "VersatileDiffusionTextToImagePipeline",
+        "VersatileDiffusionPipeline",
+        "VersatileDiffusionDualGuidedPipeline",
+        "StableDiffusionImageVariationPipeline",
+        "UnCLIPPipeline",
     ] and is_paddlenlp_version("<", "2.5.0"):
         raise ImportError(
             f"You need to install `paddlenlp>=2.5.0` in order to use {name}: \n```\n pip install"
-            " --upgrade paddlenlp \n```")
+            " --upgrade paddlenlp \n```"
+        )
 
-    if name in [
-            "StableDiffusionDepth2ImgPipeline",
-            "StableDiffusionPix2PixZeroPipeline"
-    ] and is_paddlenlp_version(
-            "<",
-            "2.5.1"  # TODO version
+    if name in ["StableDiffusionDepth2ImgPipeline", "StableDiffusionPix2PixZeroPipeline"] and is_paddlenlp_version(
+        "<", "2.5.1"  # TODO version
     ):
         raise ImportError(
             f"You need to install `paddlenlp>=2.5.1` in order to use {name}: \n```\n pip install"
-            " --upgrade paddlenlp \n```")
+            " --upgrade paddlenlp \n```"
+        )
 
 
 class DummyObject(type):
@@ -545,15 +583,13 @@ class DummyObject(type):
     """
 
     def __getattr__(cls, key):
-        if key.startswith("_"):
+        if key.startswith("_") and key != "_load_connected_pipes":
             return super().__getattr__(cls, key)
         requires_backends(cls, cls._backends)
 
 
 # This function was copied from: https://github.com/huggingface/accelerate/blob/874c4967d94badd24f893064cc3bef45f57cadf7/src/accelerate/utils/versions.py#L319
-def compare_versions(library_or_version: Union[str, Version],
-                     operation: str,
-                     requirement_version: str):
+def compare_versions(library_or_version: Union[str, Version], operation: str, requirement_version: str):
     """
     Args:
     Compares a library version to some requirement using a given operation.
@@ -565,13 +601,10 @@ def compare_versions(library_or_version: Union[str, Version],
             The version to compare the library version against
     """
     if operation not in STR_OPERATION_TO_FUNC.keys():
-        raise ValueError(
-            f"`operation` must be one of {list(STR_OPERATION_TO_FUNC.keys())}, received {operation}"
-        )
+        raise ValueError(f"`operation` must be one of {list(STR_OPERATION_TO_FUNC.keys())}, received {operation}")
     operation = STR_OPERATION_TO_FUNC[operation]
     if isinstance(library_or_version, str):
-        library_or_version = parse(
-            importlib_metadata.version(library_or_version))
+        library_or_version = parse(importlib_metadata.version(library_or_version))
     return operation(library_or_version, parse(requirement_version))
 
 
