@@ -11,16 +11,18 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
+import tempfile
 import unittest
 
+import numpy as np
 import paddle
 
+from ppdiffusers import DiffusionPipeline
 from ppdiffusers.models.attention_processor import Attention, AttnAddedKVProcessor
 
 
 class AttnAddedKVProcessorTests(unittest.TestCase):
-    def get_constructor_arguments(self, only_cross_attention: bool=False):
+    def get_constructor_arguments(self, only_cross_attention: bool = False):
         query_dim = 10
 
         if only_cross_attention:
@@ -58,8 +60,7 @@ class AttnAddedKVProcessorTests(unittest.TestCase):
 
         paddle.seed(0)
 
-        constructor_args = self.get_constructor_arguments(
-            only_cross_attention=False)
+        constructor_args = self.get_constructor_arguments(only_cross_attention=False)
         attn = Attention(**constructor_args)
 
         self.assertTrue(attn.to_k is not None)
@@ -67,7 +68,8 @@ class AttnAddedKVProcessorTests(unittest.TestCase):
 
         forward_args = self.get_forward_arguments(
             query_dim=constructor_args["query_dim"],
-            added_kv_proj_dim=constructor_args["added_kv_proj_dim"])
+            added_kv_proj_dim=constructor_args["added_kv_proj_dim"],
+        )
 
         self_and_cross_attn_out = attn(**forward_args)
 
@@ -75,8 +77,7 @@ class AttnAddedKVProcessorTests(unittest.TestCase):
 
         paddle.seed(0)
 
-        constructor_args = self.get_constructor_arguments(
-            only_cross_attention=True)
+        constructor_args = self.get_constructor_arguments(only_cross_attention=True)
         attn = Attention(**constructor_args)
 
         self.assertTrue(attn.to_k is None)
@@ -84,8 +85,40 @@ class AttnAddedKVProcessorTests(unittest.TestCase):
 
         forward_args = self.get_forward_arguments(
             query_dim=constructor_args["query_dim"],
-            added_kv_proj_dim=constructor_args["added_kv_proj_dim"])
+            added_kv_proj_dim=constructor_args["added_kv_proj_dim"],
+        )
 
         only_cross_attn_out = attn(**forward_args)
 
         self.assertTrue((only_cross_attn_out != self_and_cross_attn_out).all())
+
+
+class DeprecatedAttentionBlockTests(unittest.TestCase):
+    def test_conversion_when_using_device_map(self):
+        pipe = DiffusionPipeline.from_pretrained("hf-internal-testing/tiny-stable-diffusion-pipe", safety_checker=None)
+        pre_conversion = pipe(
+            "foo",
+            num_inference_steps=2,
+            generator=paddle.Generator().manual_seed(0),
+            output_type="np",
+        ).images
+        pipe = DiffusionPipeline.from_pretrained(
+            "hf-internal-testing/tiny-stable-diffusion-pipe", device_map="sequential", safety_checker=None
+        )
+        conversion = pipe(
+            "foo",
+            num_inference_steps=2,
+            generator=paddle.Generator().manual_seed(0),
+            output_type="np",
+        ).images
+        with tempfile.TemporaryDirectory() as tmpdir:
+            pipe.save_pretrained(tmpdir)
+            pipe = DiffusionPipeline.from_pretrained(tmpdir, device_map="sequential", safety_checker=None)
+        after_conversion = pipe(
+            "foo",
+            num_inference_steps=2,
+            generator=paddle.Generator().manual_seed(0),
+            output_type="np",
+        ).images
+        self.assertTrue(np.allclose(pre_conversion, conversion, atol=1e-03, rtol=1e-03))
+        self.assertTrue(np.allclose(conversion, after_conversion, atol=1e-03, rtol=1e-03))
