@@ -24,27 +24,26 @@ from ppdiffusers import (
     IFInpaintingPipeline,
     IFInpaintingSuperResolutionPipeline,
     IFPipeline,
-    IFSuperResolutionPipeline, )
+    IFSuperResolutionPipeline,
+)
 from ppdiffusers.models.attention_processor import AttnAddedKVProcessor
 from ppdiffusers.utils.testing_utils import (
     floats_tensor,
     load_numpy,
     require_paddle_gpu,
-    slow, )
+    slow,
+)
 
 from ..pipeline_params import TEXT_TO_IMAGE_BATCH_PARAMS, TEXT_TO_IMAGE_PARAMS
 from ..test_pipelines_common import PipelineTesterMixin, assert_mean_pixel_difference
 from . import IFPipelineTesterMixin
 
 
-class IFPipelineFastTests(PipelineTesterMixin, IFPipelineTesterMixin,
-                          unittest.TestCase):
+class IFPipelineFastTests(PipelineTesterMixin, IFPipelineTesterMixin, unittest.TestCase):
     pipeline_class = IFPipeline
     params = TEXT_TO_IMAGE_PARAMS - {"width", "height", "latents"}
     batch_params = TEXT_TO_IMAGE_BATCH_PARAMS
-    required_optional_params = PipelineTesterMixin.required_optional_params - {
-        "latents"
-    }
+    required_optional_params = PipelineTesterMixin.required_optional_params - {"latents"}
 
     def get_dummy_components(self):
         return self._get_dummy_components()
@@ -75,11 +74,12 @@ class IFPipelineFastTests(PipelineTesterMixin, IFPipelineTesterMixin,
         self._test_save_load_local()
 
     def test_inference_batch_single_identical(self):
-        self._test_inference_batch_single_identical(expected_max_diff=1e-2, )
+        self._test_inference_batch_single_identical(
+            expected_max_diff=1e-2,
+        )
 
     def test_xformers_attention_forwardGenerator_pass(self):
-        self._test_xformers_attention_forwardGenerator_pass(
-            expected_max_diff=1e-3)
+        self._test_xformers_attention_forwardGenerator_pass(expected_max_diff=1e-3)
 
 
 @slow
@@ -94,24 +94,17 @@ class IFPipelineSlowTests(unittest.TestCase):
     def test_all(self):
         # if
 
-        pipe_1 = IFPipeline.from_pretrained(
-            "DeepFloyd/IF-I-XL-v1.0",
-            variant="fp16",
-            paddle_dtype=paddle.float16)
+        pipe_1 = IFPipeline.from_pretrained("DeepFloyd/IF-I-XL-v1.0", variant="fp16", paddle_dtype=paddle.float16)
 
         pipe_2 = IFSuperResolutionPipeline.from_pretrained(
-            "DeepFloyd/IF-II-L-v1.0",
-            variant="fp16",
-            paddle_dtype=paddle.float16,
-            text_encoder=None,
-            tokenizer=None)
+            "DeepFloyd/IF-II-L-v1.0", variant="fp16", paddle_dtype=paddle.float16, text_encoder=None, tokenizer=None
+        )
 
         # pre compute text embeddings and remove T5 to save memory
 
         pipe_1.text_encoder
 
-        prompt_embeds, negative_prompt_embeds = pipe_1.encode_prompt(
-            "anime turtle")
+        prompt_embeds, negative_prompt_embeds = pipe_1.encode_prompt("anime turtle")
 
         del pipe_1.tokenizer
         del pipe_1.text_encoder
@@ -120,47 +113,30 @@ class IFPipelineSlowTests(unittest.TestCase):
         pipe_1.tokenizer = None
         pipe_1.text_encoder = None
 
-        pipe_1.enable_model_cpu_offload()
-        pipe_2.enable_model_cpu_offload()
-
         pipe_1.unet.set_attn_processor(AttnAddedKVProcessor())
         pipe_2.unet.set_attn_processor(AttnAddedKVProcessor())
 
         self._test_if(pipe_1, pipe_2, prompt_embeds, negative_prompt_embeds)
 
-        pipe_1.remove_all_hooks()
-        pipe_2.remove_all_hooks()
-
         # img2img
 
         pipe_1 = IFImg2ImgPipeline(**pipe_1.components)
         pipe_2 = IFImg2ImgSuperResolutionPipeline(**pipe_2.components)
 
-        pipe_1.enable_model_cpu_offload()
-        pipe_2.enable_model_cpu_offload()
-
         pipe_1.unet.set_attn_processor(AttnAddedKVProcessor())
         pipe_2.unet.set_attn_processor(AttnAddedKVProcessor())
 
-        self._test_if_img2img(pipe_1, pipe_2, prompt_embeds,
-                              negative_prompt_embeds)
-
-        pipe_1.remove_all_hooks()
-        pipe_2.remove_all_hooks()
+        self._test_if_img2img(pipe_1, pipe_2, prompt_embeds, negative_prompt_embeds)
 
         # inpainting
 
         pipe_1 = IFInpaintingPipeline(**pipe_1.components)
         pipe_2 = IFInpaintingSuperResolutionPipeline(**pipe_2.components)
 
-        pipe_1.enable_model_cpu_offload()
-        pipe_2.enable_model_cpu_offload()
-
         pipe_1.unet.set_attn_processor(AttnAddedKVProcessor())
         pipe_2.unet.set_attn_processor(AttnAddedKVProcessor())
 
-        self._test_if_inpainting(pipe_1, pipe_2, prompt_embeds,
-                                 negative_prompt_embeds)
+        self._test_if_inpainting(pipe_1, pipe_2, prompt_embeds, negative_prompt_embeds)
 
     def _test_if(self, pipe_1, pipe_2, prompt_embeds, negative_prompt_embeds):
         # pipeline 1
@@ -171,17 +147,18 @@ class IFPipelineSlowTests(unittest.TestCase):
             negative_prompt_embeds=negative_prompt_embeds,
             num_inference_steps=2,
             generator=generator,
-            output_type="np", )
+            output_type="np",
+        )
 
         image = output.images[0]
 
         assert image.shape == (64, 64, 3)
 
-        mem_bytes = paddle.cuda.max_memory_allocated()
-        assert mem_bytes < 13 * 10**9
+        mem_bytes = paddle.device.cuda.max_memory_allocated()
+        assert mem_bytes < 30 * 10**9
 
         expected_image = load_numpy(
-            "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/if/test_if.npy"
+            "https://bj.bcebos.com/v1/paddlenlp/models/community/hf-internal-testing/deepfloyd_if/test_if.npy"
         )
         assert_mean_pixel_difference(image, expected_image)
 
@@ -197,22 +174,22 @@ class IFPipelineSlowTests(unittest.TestCase):
             image=image,
             generator=generator,
             num_inference_steps=2,
-            output_type="np", )
+            output_type="np",
+        )
 
         image = output.images[0]
 
         assert image.shape == (256, 256, 3)
 
-        mem_bytes = paddle.cuda.max_memory_allocated()
-        assert mem_bytes < 4 * 10**9
+        mem_bytes = paddle.device.cuda.max_memory_allocated()
+        assert mem_bytes < 30 * 10**9
 
         expected_image = load_numpy(
-            "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/if/test_if_superresolution_stage_II.npy"
+            "https://bj.bcebos.com/v1/paddlenlp/models/community/hf-internal-testing/deepfloyd_if/test_if_superresolution_stage_II.npy"
         )
         assert_mean_pixel_difference(image, expected_image)
 
-    def _test_if_img2img(self, pipe_1, pipe_2, prompt_embeds,
-                         negative_prompt_embeds):
+    def _test_if_img2img(self, pipe_1, pipe_2, prompt_embeds, negative_prompt_embeds):
         # pipeline 1
 
         image = floats_tensor((1, 3, 64, 64), rng=random.Random(0))
@@ -225,17 +202,18 @@ class IFPipelineSlowTests(unittest.TestCase):
             image=image,
             num_inference_steps=2,
             generator=generator,
-            output_type="np", )
+            output_type="np",
+        )
 
         image = output.images[0]
 
         assert image.shape == (64, 64, 3)
 
-        mem_bytes = paddle.cuda.max_memory_allocated()
-        assert mem_bytes < 10 * 10**9
+        mem_bytes = paddle.device.cuda.max_memory_allocated()
+        assert mem_bytes < 30 * 10**9
 
         expected_image = load_numpy(
-            "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/if/test_if_img2img.npy"
+            "https://bj.bcebos.com/v1/paddlenlp/models/community/hf-internal-testing/deepfloyd_if/test_if_img2img.npy"
         )
         assert_mean_pixel_difference(image, expected_image)
 
@@ -253,22 +231,22 @@ class IFPipelineSlowTests(unittest.TestCase):
             original_image=original_image,
             generator=generator,
             num_inference_steps=2,
-            output_type="np", )
+            output_type="np",
+        )
 
         image = output.images[0]
 
         assert image.shape == (256, 256, 3)
 
-        mem_bytes = paddle.cuda.max_memory_allocated()
-        assert mem_bytes < 4 * 10**9
+        mem_bytes = paddle.device.cuda.max_memory_allocated()
+        assert mem_bytes < 30 * 10**9
 
         expected_image = load_numpy(
-            "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/if/test_if_img2img_superresolution_stage_II.npy"
+            "https://bj.bcebos.com/v1/paddlenlp/models/community/hf-internal-testing/deepfloyd_if/test_if_img2img_superresolution_stage_II.npy"
         )
         assert_mean_pixel_difference(image, expected_image)
 
-    def _test_if_inpainting(self, pipe_1, pipe_2, prompt_embeds,
-                            negative_prompt_embeds):
+    def _test_if_inpainting(self, pipe_1, pipe_2, prompt_embeds, negative_prompt_embeds):
         # pipeline 1
 
         image = floats_tensor((1, 3, 64, 64), rng=random.Random(0))
@@ -282,17 +260,17 @@ class IFPipelineSlowTests(unittest.TestCase):
             mask_image=mask_image,
             num_inference_steps=2,
             generator=generator,
-            output_type="np", )
+            output_type="np",
+        )
 
         image = output.images[0]
 
         assert image.shape == (64, 64, 3)
 
-        mem_bytes = paddle.cuda.max_memory_allocated()
-        assert mem_bytes < 10 * 10**9
-
+        mem_bytes = paddle.device.cuda.max_memory_allocated()
+        assert mem_bytes < 30 * 10**9
         expected_image = load_numpy(
-            "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/if/test_if_inpainting.npy"
+            "https://bj.bcebos.com/v1/paddlenlp/models/community/hf-internal-testing/deepfloyd_if/test_if_inpainting.npy"
         )
         assert_mean_pixel_difference(image, expected_image)
 
@@ -312,16 +290,17 @@ class IFPipelineSlowTests(unittest.TestCase):
             original_image=original_image,
             generator=generator,
             num_inference_steps=2,
-            output_type="np", )
+            output_type="np",
+        )
 
         image = output.images[0]
 
         assert image.shape == (256, 256, 3)
 
         mem_bytes = paddle.device.cuda.max_memory_allocated()
-        assert mem_bytes < 4 * 10**9
+        assert mem_bytes < 30 * 10**9
 
         expected_image = load_numpy(
-            "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/if/test_if_inpainting_superresolution_stage_II.npy"
+            "https://bj.bcebos.com/v1/paddlenlp/models/community/hf-internal-testing/deepfloyd_if/test_if_inpainting_superresolution_stage_II.npy"
         )
         assert_mean_pixel_difference(image, expected_image)
