@@ -22,13 +22,15 @@ from ppdiffusers import DDPMScheduler, MidiProcessor, SpectrogramDiffusionPipeli
 from ppdiffusers.pipelines.spectrogram_diffusion import (
     SpectrogramContEncoder,
     SpectrogramNotesEncoder,
-    T5FilmDecoder, )
+    T5FilmDecoder,
+)
 from ppdiffusers.training_utils import enable_full_determinism
 from ppdiffusers.utils import require_paddle_gpu, slow
 
 from ..pipeline_params import (
     TOKENS_TO_AUDIO_GENERATION_BATCH_PARAMS,
-    TOKENS_TO_AUDIO_GENERATION_PARAMS, )
+    TOKENS_TO_AUDIO_GENERATION_PARAMS,
+)
 from ..test_pipelines_common import PipelineTesterMixin
 
 enable_full_determinism(42)
@@ -40,8 +42,7 @@ MIDI_FILE = "./tests/fixtures/elise_format0.mid"
 # is not compatible with python 3.8 which we run in the CI.
 # https://github.com/huggingface/diffusers/actions/runs/4830121056/jobs/8605954838#step:7:98
 # @unittest.skip("The note-seq package currently throws an error on import")
-class SpectrogramDiffusionPipelineFastTests(PipelineTesterMixin,
-                                            unittest.TestCase):
+class SpectrogramDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
     pipeline_class = SpectrogramDiffusionPipeline
     required_optional_params = PipelineTesterMixin.required_optional_params - {
         "callback",
@@ -67,7 +68,8 @@ class SpectrogramDiffusionPipelineFastTests(PipelineTesterMixin,
             num_heads=1,
             d_kv=4,
             d_ff=2048,
-            feed_forward_proj="gated-gelu", )
+            feed_forward_proj="gated-gelu",
+        )
         notes_encoder.eval()
         paddle.seed(0)
         continuous_encoder = SpectrogramContEncoder(
@@ -79,7 +81,8 @@ class SpectrogramDiffusionPipelineFastTests(PipelineTesterMixin,
             num_heads=1,
             d_kv=4,
             d_ff=2048,
-            feed_forward_proj="gated-gelu", )
+            feed_forward_proj="gated-gelu",
+        )
         continuous_encoder.eval()
 
         paddle.seed(0)
@@ -92,7 +95,8 @@ class SpectrogramDiffusionPipelineFastTests(PipelineTesterMixin,
             num_heads=1,
             d_kv=4,
             d_ff=2048,
-            dropout_rate=0.1, )
+            dropout_rate=0.1,
+        )
         decoder.eval()
 
         scheduler = DDPMScheduler()
@@ -110,10 +114,9 @@ class SpectrogramDiffusionPipelineFastTests(PipelineTesterMixin,
 
         generator = paddle.Generator().manual_seed(seed)
         inputs = {
-            "input_tokens": [[
-                1134, 90, 1135, 1133, 1080, 112, 1132, 1080, 1133, 1079, 133,
-                1132, 1079, 1133, 1
-            ] + [0] * 2033],
+            "input_tokens": [
+                [1134, 90, 1135, 1133, 1080, 112, 1132, 1080, 1133, 1079, 133, 1132, 1079, 1133, 1] + [0] * 2033
+            ],
             "generator": generator,
             "num_inference_steps": 4,
             "output_type": "mel",
@@ -133,10 +136,9 @@ class SpectrogramDiffusionPipelineFastTests(PipelineTesterMixin,
         mel_slice = mel[0, -3:, -3:]
 
         assert mel_slice.shape == (3, 3)
-        expected_slice = np.array([
-            -11.46511, 4.0, -8.506372, -11.512925, -11.512925, -10.417862,
-            -8.077912, 3.7985802, 4.0
-        ])
+        expected_slice = np.array(
+            [-11.46511, 4.0, -8.506372, -11.512925, -11.512925, -10.417862, -8.077912, 3.7985802, 4.0]
+        )
         assert np.abs(mel_slice.flatten() - expected_slice).max() < 1e-2
 
     def test_save_load_local(self):
@@ -173,8 +175,7 @@ class PipelineIntegrationTests(unittest.TestCase):
     def test_callback(self):
         # TODO - test that pipeline can decode tokens in a callback
         # so that music can be played live
-        pipe = SpectrogramDiffusionPipeline.from_pretrained(
-            "google/music-spectrogram-diffusion")
+        pipe = SpectrogramDiffusionPipeline.from_pretrained("google/music-spectrogram-diffusion")
         melgan = pipe.melgan
         pipe.melgan = None
 
@@ -192,17 +193,11 @@ class PipelineIntegrationTests(unittest.TestCase):
 
         input_tokens = input_tokens[:3]
         generator = paddle.Generator().manual_seed(0)
-        pipe(
-            input_tokens,
-            num_inference_steps=5,
-            generator=generator,
-            callback=callback,
-            output_type="mel")
+        pipe(input_tokens, num_inference_steps=5, generator=generator, callback=callback, output_type="mel")
 
     def test_spectrogram_fast(self):
 
-        pipe = SpectrogramDiffusionPipeline.from_pretrained(
-            "google/music-spectrogram-diffusion")
+        pipe = SpectrogramDiffusionPipeline.from_pretrained("google/music-spectrogram-diffusion")
         pipe.set_progress_bar_config(disable=None)
         processor = MidiProcessor()
 
@@ -219,8 +214,7 @@ class PipelineIntegrationTests(unittest.TestCase):
 
     def test_spectrogram(self):
 
-        pipe = SpectrogramDiffusionPipeline.from_pretrained(
-            "google/music-spectrogram-diffusion")
+        pipe = SpectrogramDiffusionPipeline.from_pretrained("google/music-spectrogram-diffusion")
         pipe.set_progress_bar_config(disable=None)
 
         processor = MidiProcessor()
@@ -231,8 +225,7 @@ class PipelineIntegrationTests(unittest.TestCase):
         input_tokens = input_tokens[:4]
 
         generator = paddle.Generator().manual_seed(0)
-        output = pipe(
-            input_tokens, num_inference_steps=100, generator=generator)
+        output = pipe(input_tokens, num_inference_steps=100, generator=generator)
 
         audio = output.audios[0]
         assert abs(np.abs(audio).sum() - 14418.089) < 5e-2
