@@ -19,22 +19,28 @@ import unittest
 
 import numpy as np
 import paddle
-from ..pipeline_params import (
-    TEXT_GUIDED_IMAGE_VARIATION_BATCH_PARAMS,
-    TEXT_GUIDED_IMAGE_VARIATION_PARAMS, )
-from ..test_pipelines_common import PipelineTesterMixin
-
 from paddlenlp.transformers import CLIPTextConfig, CLIPTextModel, CLIPTokenizer
+
 from ppdiffusers import (
     AutoencoderKL,
     CycleDiffusionPipeline,
     DDIMScheduler,
-    UNet2DConditionModel, )
+    UNet2DConditionModel,
+)
 from ppdiffusers.utils import floats_tensor, load_image, slow
-from ppdiffusers.utils.testing_utils import require_paddle_gpu
+from ppdiffusers.utils.testing_utils import enable_full_determinism, require_paddle_gpu
+
+from ..pipeline_params import (
+    IMAGE_TO_IMAGE_IMAGE_PARAMS,
+    TEXT_GUIDED_IMAGE_VARIATION_BATCH_PARAMS,
+    TEXT_GUIDED_IMAGE_VARIATION_PARAMS,
+)
+from ..test_pipelines_common import PipelineLatentTesterMixin, PipelineTesterMixin
+
+enable_full_determinism()
 
 
-class CycleDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
+class CycleDiffusionPipelineFastTests(PipelineLatentTesterMixin, PipelineTesterMixin, unittest.TestCase):
     pipeline_class = CycleDiffusionPipeline
     params = TEXT_GUIDED_IMAGE_VARIATION_PARAMS - {
         "negative_prompt",
@@ -42,11 +48,10 @@ class CycleDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
         "width",
         "negative_prompt_embeds",
     }
-    required_optional_params = PipelineTesterMixin.required_optional_params - {
-        "latents"
-    }
-    batch_params = TEXT_GUIDED_IMAGE_VARIATION_BATCH_PARAMS.union(
-        {"source_prompt"})
+    required_optional_params = PipelineTesterMixin.required_optional_params - {"latents"}
+    batch_params = TEXT_GUIDED_IMAGE_VARIATION_BATCH_PARAMS.union({"source_prompt"})
+    image_params = IMAGE_TO_IMAGE_IMAGE_PARAMS
+    image_latents_params = IMAGE_TO_IMAGE_IMAGE_PARAMS
 
     def get_dummy_components(self):
         paddle.seed(0)
@@ -58,14 +63,16 @@ class CycleDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
             out_channels=4,
             down_block_types=("DownBlock2D", "CrossAttnDownBlock2D"),
             up_block_types=("CrossAttnUpBlock2D", "UpBlock2D"),
-            cross_attention_dim=32, )
+            cross_attention_dim=32,
+        )
         scheduler = DDIMScheduler(
             beta_start=0.00085,
             beta_end=0.012,
             beta_schedule="scaled_linear",
             num_train_timesteps=1000,
             clip_sample=False,
-            set_alpha_to_one=False, )
+            set_alpha_to_one=False,
+        )
         paddle.seed(0)
         vae = AutoencoderKL(
             block_out_channels=[32, 64],
@@ -73,7 +80,8 @@ class CycleDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
             out_channels=3,
             down_block_types=["DownEncoderBlock2D", "DownEncoderBlock2D"],
             up_block_types=["UpDecoderBlock2D", "UpDecoderBlock2D"],
-            latent_channels=4, )
+            latent_channels=4,
+        )
         paddle.seed(0)
         text_encoder_config = CLIPTextConfig(
             bos_token_id=0,
@@ -84,10 +92,10 @@ class CycleDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
             num_attention_heads=4,
             num_hidden_layers=5,
             pad_token_id=1,
-            vocab_size=1000, )
+            vocab_size=1000,
+        )
         text_encoder = CLIPTextModel(text_encoder_config).eval()
-        tokenizer = CLIPTokenizer.from_pretrained(
-            "hf-internal-testing/tiny-random-clip")
+        tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
         components = {
             "unet": unet,
             "scheduler": scheduler,
@@ -101,6 +109,7 @@ class CycleDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
 
     def get_dummy_inputs(self, seed=0):
         image = floats_tensor((1, 3, 32, 32), rng=random.Random(seed))
+        image = image / 2 + 0.5
         generator = paddle.Generator().manual_seed(seed)
 
         inputs = {
@@ -113,7 +122,7 @@ class CycleDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
             "strength": 0.8,
             "guidance_scale": 3,
             "source_guidance_scale": 1,
-            "output_type": "numpy",
+            "output_type": "np",
         }
         return inputs
 
@@ -126,10 +135,9 @@ class CycleDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
         images = output.images
         image_slice = images[0, -3:, -3:, -1]
         assert images.shape == (1, 32, 32, 3)
-        expected_slice = np.array([
-            0.04812625, 0.77983606, 0.71009433, 0.15924984, 0.9788434,
-            0.49732354, 0.362224, 0.6481595, 0.4530744
-        ])
+        expected_slice = np.array(
+            [0.04812625, 0.77983606, 0.71009433, 0.15924984, 0.9788434, 0.49732354, 0.362224, 0.6481595, 0.4530744]
+        )
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
     def test_stable_diffusion_cycle_fp16(self):
@@ -144,10 +152,9 @@ class CycleDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
         images = output.images
         image_slice = images[0, -3:, -3:, -1]
         assert images.shape == (1, 32, 32, 3)
-        expected_slice = np.array([
-            0.05053711, 0.78125, 0.7114258, 0.15991211, 0.9785156, 0.49804688,
-            0.36279297, 0.6484375, 0.45361328
-        ])
+        expected_slice = np.array(
+            [0.05053711, 0.78125, 0.7114258, 0.15991211, 0.9785156, 0.49804688, 0.36279297, 0.6484375, 0.45361328]
+        )
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
     @unittest.skip("non-deterministic pipeline")
@@ -165,20 +172,15 @@ class CycleDiffusionPipelineIntegrationTests(unittest.TestCase):
 
     def test_cycle_diffusion_pipeline_fp16(self):
         init_image = load_image(
-            "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/cycle-diffusion/black_colored_car.png"
+            "https://bj.bcebos.com/v1/paddlenlp/datasets/hf-internal-testing/diffusers-images/resolve/main/cycle-diffusion/black_colored_car.png"
         )
-        expected_image = np.array([[0.14477539, 0.20483398, 0.14135742],
-                                   [0.10009766, 0.17602539, 0.11083984]])
+        expected_image = np.array([[0.14477539, 0.20483398, 0.14135742], [0.10009766, 0.17602539, 0.11083984]])
         init_image = init_image.resize((512, 512))
         model_id = "CompVis/stable-diffusion-v1-4"
-        scheduler = DDIMScheduler.from_pretrained(
-            model_id, subfolder="scheduler")
+        scheduler = DDIMScheduler.from_pretrained(model_id, subfolder="scheduler")
         pipe = CycleDiffusionPipeline.from_pretrained(
-            model_id,
-            scheduler=scheduler,
-            safety_checker=None,
-            paddle_dtype=paddle.float16,
-            revision="fp16")
+            model_id, scheduler=scheduler, safety_checker=None, paddle_dtype=paddle.float16, revision="fp16"
+        )
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
         source_prompt = "A black colored car"
@@ -194,22 +196,20 @@ class CycleDiffusionPipelineIntegrationTests(unittest.TestCase):
             guidance_scale=3,
             source_guidance_scale=1,
             generator=generator,
-            output_type="np", )
+            output_type="np",
+        )
         image = output.images
         assert np.abs(image[0][0][:2] - expected_image).max() < 0.5
 
     def test_cycle_diffusion_pipeline(self):
         init_image = load_image(
-            "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/cycle-diffusion/black_colored_car.png"
+            "https://bj.bcebos.com/v1/paddlenlp/datasets/hf-internal-testing/diffusers-images/resolve/main/cycle-diffusion/black_colored_car.png"
         )
-        expected_image = np.array([[0.16294342, 0.20514232, 0.14554858],
-                                   [0.11476257, 0.16831946, 0.11495486]])
+        expected_image = np.array([[0.16294342, 0.20514232, 0.14554858], [0.11476257, 0.16831946, 0.11495486]])
         init_image = init_image.resize((512, 512))
         model_id = "CompVis/stable-diffusion-v1-4"
-        scheduler = DDIMScheduler.from_pretrained(
-            model_id, subfolder="scheduler")
-        pipe = CycleDiffusionPipeline.from_pretrained(
-            model_id, scheduler=scheduler, safety_checker=None)
+        scheduler = DDIMScheduler.from_pretrained(model_id, subfolder="scheduler")
+        pipe = CycleDiffusionPipeline.from_pretrained(model_id, scheduler=scheduler, safety_checker=None)
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
         source_prompt = "A black colored car"
@@ -225,6 +225,7 @@ class CycleDiffusionPipelineIntegrationTests(unittest.TestCase):
             guidance_scale=3,
             source_guidance_scale=1,
             generator=generator,
-            output_type="np", )
+            output_type="np",
+        )
         image = output.images
         assert np.abs(image[0][0][:2] - expected_image).max() < 0.01
