@@ -20,40 +20,52 @@ import unittest
 
 import numpy as np
 import paddle
-from PIL import Image
-
 from paddlenlp.transformers import (
     CLIPTextConfig,
     CLIPTextModel,
     CLIPTokenizer,
     DPTConfig,
     DPTForDepthEstimation,
-    DPTImageProcessor, )
+    DPTImageProcessor,
+)
+from PIL import Image
+
 from ppdiffusers import (
     AutoencoderKL,
     DDIMScheduler,
     LMSDiscreteScheduler,
     PNDMScheduler,
     StableDiffusionDepth2ImgPipeline,
-    UNet2DConditionModel, )
+    UNet2DConditionModel,
+)
 from ppdiffusers.utils import floats_tensor, load_image, nightly, slow
-from ppdiffusers.utils.testing_utils import require_paddle_gpu
+from ppdiffusers.utils.testing_utils import enable_full_determinism, require_paddle_gpu
 
 from ..pipeline_params import (
+    IMAGE_TO_IMAGE_IMAGE_PARAMS,
     TEXT_GUIDED_IMAGE_VARIATION_BATCH_PARAMS,
-    TEXT_GUIDED_IMAGE_VARIATION_PARAMS, )
-from ..test_pipelines_common import PipelineTesterMixin
+    TEXT_GUIDED_IMAGE_VARIATION_PARAMS,
+    TEXT_TO_IMAGE_IMAGE_PARAMS,
+)
+from ..test_pipelines_common import (
+    PipelineKarrasSchedulerTesterMixin,
+    PipelineLatentTesterMixin,
+    PipelineTesterMixin,
+)
+
+enable_full_determinism()
 
 
-class StableDiffusionDepth2ImgPipelineFastTests(PipelineTesterMixin,
-                                                unittest.TestCase):
+class StableDiffusionDepth2ImgPipelineFastTests(
+    PipelineLatentTesterMixin, PipelineKarrasSchedulerTesterMixin, PipelineTesterMixin, unittest.TestCase
+):
     pipeline_class = StableDiffusionDepth2ImgPipeline
     test_save_load_optional_components = False
     params = TEXT_GUIDED_IMAGE_VARIATION_PARAMS - {"height", "width"}
-    required_optional_params = PipelineTesterMixin.required_optional_params - {
-        "latents"
-    }
+    required_optional_params = PipelineTesterMixin.required_optional_params - {"latents"}
     batch_params = TEXT_GUIDED_IMAGE_VARIATION_BATCH_PARAMS
+    image_params = IMAGE_TO_IMAGE_IMAGE_PARAMS
+    image_latents_params = TEXT_TO_IMAGE_IMAGE_PARAMS
 
     def get_dummy_components(self):
         paddle.seed(0)
@@ -67,7 +79,8 @@ class StableDiffusionDepth2ImgPipelineFastTests(PipelineTesterMixin,
             up_block_types=("CrossAttnUpBlock2D", "UpBlock2D"),
             cross_attention_dim=32,
             attention_head_dim=(2, 4),
-            use_linear_projection=True, )
+            use_linear_projection=True,
+        )
         scheduler = PNDMScheduler(skip_prk_steps=True)
         paddle.seed(0)
         vae = AutoencoderKL(
@@ -76,7 +89,8 @@ class StableDiffusionDepth2ImgPipelineFastTests(PipelineTesterMixin,
             out_channels=3,
             down_block_types=["DownEncoderBlock2D", "DownEncoderBlock2D"],
             up_block_types=["UpDecoderBlock2D", "UpDecoderBlock2D"],
-            latent_channels=4, )
+            latent_channels=4,
+        )
         paddle.seed(0)
         text_encoder_config = CLIPTextConfig(
             bos_token_id=0,
@@ -87,10 +101,10 @@ class StableDiffusionDepth2ImgPipelineFastTests(PipelineTesterMixin,
             num_attention_heads=4,
             num_hidden_layers=5,
             pad_token_id=1,
-            vocab_size=1000, )
+            vocab_size=1000,
+        )
         text_encoder = CLIPTextModel(text_encoder_config).eval()
-        tokenizer = CLIPTokenizer.from_pretrained(
-            "hf-internal-testing/tiny-random-clip")
+        tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
         backbone_config = {
             "global_padding": "same",
             "layer_type": "bottleneck",
@@ -116,10 +130,10 @@ class StableDiffusionDepth2ImgPipelineFastTests(PipelineTesterMixin,
             initializer_range=0.02,
             is_hybrid=True,
             backbone_config=backbone_config,
-            backbone_featmap_shape=[1, 384, 24, 24], )
-        depth_estimator = DPTForDepthEstimation(depth_estimator_config)
-        feature_extractor = DPTImageProcessor.from_pretrained(
-            "hf-internal-testing/tiny-random-DPTForDepthEstimation")
+            backbone_featmap_shape=[1, 384, 24, 24],
+        )
+        depth_estimator = DPTForDepthEstimation(depth_estimator_config).eval()
+        feature_extractor = DPTImageProcessor.from_pretrained("hf-internal-testing/tiny-random-DPTForDepthEstimation")
         components = {
             "unet": unet,
             "scheduler": scheduler,
@@ -143,7 +157,7 @@ class StableDiffusionDepth2ImgPipelineFastTests(PipelineTesterMixin,
             "generator": generator,
             "num_inference_steps": 2,
             "guidance_scale": 6.0,
-            "output_type": "numpy",
+            "output_type": "np",
         }
         return inputs
 
@@ -155,8 +169,7 @@ class StableDiffusionDepth2ImgPipelineFastTests(PipelineTesterMixin,
         output = pipe(**inputs)[0]
         with tempfile.TemporaryDirectory() as tmpdir:
             pipe.save_pretrained(tmpdir)
-            pipe_loaded = self.pipeline_class.from_pretrained(
-                tmpdir, from_diffusers=False)
+            pipe_loaded = self.pipeline_class.from_pretrained(tmpdir, from_diffusers=False)
             pipe_loaded.set_progress_bar_config(disable=None)
         inputs = self.get_dummy_inputs()
         output_loaded = pipe_loaded(**inputs)[0]
@@ -224,10 +237,9 @@ class StableDiffusionDepth2ImgPipelineFastTests(PipelineTesterMixin,
         image = pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1]
         assert image.shape == (1, 32, 32, 3)
-        expected_slice = np.array([
-            0.35397637, 0.23190483, 0.20131412, 0.27374774, 0.265134, 0.4502194,
-            0.26852018, 0.37504935, 0.43135768
-        ])
+        expected_slice = np.array(
+            [0.35397637, 0.23190483, 0.20131412, 0.27374774, 0.265134, 0.4502194, 0.26852018, 0.37504935, 0.43135768]
+        )
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.001
 
     def test_stable_diffusion_depth2img_negative_prompt(self):
@@ -240,11 +252,10 @@ class StableDiffusionDepth2ImgPipelineFastTests(PipelineTesterMixin,
         image = output.images
         image_slice = image[0, -3:, -3:, -1]
         assert image.shape == (1, 32, 32, 3)
-        expected_slice = np.array([
-            0.40259343, 0.37764466, 0.3936328, 0.3628915, 0.48100996,
-            0.59685427, 0.22927544, 0.45186657, 0.46950823
-        ])
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.001
+        expected_slice = np.array(
+            [0.40259343, 0.37764466, 0.3936328, 0.3628915, 0.48100996, 0.59685427, 0.22927544, 0.45186657, 0.46950823]
+        )
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.002
 
     def test_stable_diffusion_depth2img_multiple_init_images(self):
         components = self.get_dummy_components()
@@ -256,11 +267,10 @@ class StableDiffusionDepth2ImgPipelineFastTests(PipelineTesterMixin,
         image = pipe(**inputs).images
         image_slice = image[-1, -3:, -3:, -1]
         assert image.shape == (2, 32, 32, 3)
-        expected_slice = np.array([
-            0.8169553, 0.4573238, 0.27039874, 0.60622, 0.35670877, 0.39508212,
-            0.56803817, 0.5341117, 0.44428858
-        ])
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.001
+        expected_slice = np.array(
+            [0.8169553, 0.4573238, 0.27039874, 0.60622, 0.35670877, 0.39508212, 0.56803817, 0.5341117, 0.44428858]
+        )
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.002
 
     def test_stable_diffusion_depth2img_num_images_per_prompt(self):
         components = self.get_dummy_components()
@@ -276,14 +286,12 @@ class StableDiffusionDepth2ImgPipelineFastTests(PipelineTesterMixin,
         assert images.shape == (batch_size, 32, 32, 3)
         num_images_per_prompt = 2
         inputs = self.get_dummy_inputs()
-        images = pipe(
-            **inputs, num_images_per_prompt=num_images_per_prompt).images
+        images = pipe(**inputs, num_images_per_prompt=num_images_per_prompt).images
         assert images.shape == (num_images_per_prompt, 32, 32, 3)
         batch_size = 2
         inputs = self.get_dummy_inputs()
         inputs["prompt"] = [inputs["prompt"]] * batch_size
-        images = pipe(
-            **inputs, num_images_per_prompt=num_images_per_prompt).images
+        images = pipe(**inputs, num_images_per_prompt=num_images_per_prompt).images
         assert images.shape == (batch_size * num_images_per_prompt, 32, 32, 3)
 
     def test_stable_diffusion_depth2img_pil(self):
@@ -293,12 +301,17 @@ class StableDiffusionDepth2ImgPipelineFastTests(PipelineTesterMixin,
         inputs = self.get_dummy_inputs()
         image = pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1]
-        expected_slice = np.array([
-            0.35397637, 0.23190483, 0.20131412, 0.27374774, 0.265134, 0.4502194,
-            0.26852018, 0.37504935, 0.43135768
-        ])
+        expected_slice = np.array(
+            [0.35397637, 0.23190483, 0.20131412, 0.27374774, 0.265134, 0.4502194, 0.26852018, 0.37504935, 0.43135768]
+        )
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.001
 
+    def test_attention_slicing_forward_pass(self):
+        return super().test_attention_slicing_forward_pass()
+
+    def test_inference_batch_single_identical(self):
+        super().test_inference_batch_single_identical()
+
 
 @slow
 @require_paddle_gpu
@@ -308,10 +321,10 @@ class StableDiffusionDepth2ImgPipelineSlowTests(unittest.TestCase):
         gc.collect()
         paddle.device.cuda.empty_cache()
 
-    def get_inputs(self, dtype="float32", seed=0):
+    def get_inputs(self, seed=0):
         generator = paddle.Generator().manual_seed(seed)
         init_image = load_image(
-            "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/depth2img/two_cats.png"
+            "https://bj.bcebos.com/v1/paddlenlp/datasets/hf-internal-testing/diffusers-images/resolve/main/depth2img/two_cats.png"
         )
         inputs = {
             "prompt": "two tigers",
@@ -320,29 +333,29 @@ class StableDiffusionDepth2ImgPipelineSlowTests(unittest.TestCase):
             "num_inference_steps": 3,
             "strength": 0.75,
             "guidance_scale": 7.5,
-            "output_type": "numpy",
+            "output_type": "np",
         }
         return inputs
 
     def test_stable_diffusion_depth2img_pipeline_default(self):
         pipe = StableDiffusionDepth2ImgPipeline.from_pretrained(
-            "stabilityai/stable-diffusion-2-depth", safety_checker=None)
+            "stabilityai/stable-diffusion-2-depth", safety_checker=None
+        )
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
         inputs = self.get_inputs()
         image = pipe(**inputs).images
         image_slice = image[0, 253:256, 253:256, -1].flatten()
         assert image.shape == (1, 480, 640, 3)
-        # expected_slice = np.array([0.9057, 0.9365, 0.9258, 0.8937, 0.8555, 0.8541, 0.826, 0.7747, 0.7421])
-        expected_slice = np.array([
-            0.75446224, 0.746921, 0.7595095, 0.8161169, 0.8059271, 0.7999228,
-            0.9052905, 0.879215, 0.8690305
-        ])
+        expected_slice = np.array(
+            [0.75446224, 0.746921, 0.7595095, 0.8161169, 0.8059271, 0.7999228, 0.9052905, 0.879215, 0.8690305]
+        )
         assert np.abs(expected_slice - image_slice).max() < 0.1
 
     def test_stable_diffusion_depth2img_pipeline_k_lms(self):
         pipe = StableDiffusionDepth2ImgPipeline.from_pretrained(
-            "stabilityai/stable-diffusion-2-depth", safety_checker=None)
+            "stabilityai/stable-diffusion-2-depth", safety_checker=None
+        )
         pipe.scheduler = LMSDiscreteScheduler.from_config(pipe.scheduler.config)
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
@@ -350,16 +363,15 @@ class StableDiffusionDepth2ImgPipelineSlowTests(unittest.TestCase):
         image = pipe(**inputs).images
         image_slice = image[0, 253:256, 253:256, -1].flatten()
         assert image.shape == (1, 480, 640, 3)
-        # expected_slice = np.array([0.6363, 0.6274, 0.6309, 0.637, 0.6226, 0.6286, 0.6213, 0.6453, 0.6306])
-        expected_slice = np.array([
-            0.6395747, 0.64879197, 0.6566683, 0.6438427, 0.6707787, 0.63587487,
-            0.66576767, 0.62180007, 0.6628648
-        ])
+        expected_slice = np.array(
+            [0.6395747, 0.64879197, 0.6566683, 0.6438427, 0.6707787, 0.63587487, 0.66576767, 0.62180007, 0.6628648]
+        )
         assert np.abs(expected_slice - image_slice).max() < 0.1
 
     def test_stable_diffusion_depth2img_pipeline_ddim(self):
         pipe = StableDiffusionDepth2ImgPipeline.from_pretrained(
-            "stabilityai/stable-diffusion-2-depth", safety_checker=None)
+            "stabilityai/stable-diffusion-2-depth", safety_checker=None
+        )
         pipe.scheduler = DDIMScheduler.from_config(pipe.scheduler.config)
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
@@ -367,19 +379,16 @@ class StableDiffusionDepth2ImgPipelineSlowTests(unittest.TestCase):
         image = pipe(**inputs).images
         image_slice = image[0, 253:256, 253:256, -1].flatten()
         assert image.shape == (1, 480, 640, 3)
-        # expected_slice = np.array([0.6424, 0.6524, 0.6249, 0.6041, 0.6634, 0.642, 0.6522, 0.6555, 0.6436])
-        expected_slice = np.array([
-            0.6283968, 0.6419119, 0.6295293, 0.63652724, 0.6420511, 0.61574477,
-            0.62251365, 0.65826833, 0.6480877
-        ])
+        expected_slice = np.array(
+            [0.6283968, 0.6419119, 0.6295293, 0.63652724, 0.6420511, 0.61574477, 0.62251365, 0.65826833, 0.6480877]
+        )
 
         assert np.abs(expected_slice - image_slice).max() < 0.15
 
     def test_stable_diffusion_depth2img_intermediate_state(self):
         number_of_steps = 0
 
-        def callback_fn(step: int, timestep: int,
-                        latents: paddle.Tensor) -> None:
+        def callback_fn(step: int, timestep: int, latents: paddle.Tensor) -> None:
             callback_fn.has_been_called = True
             nonlocal number_of_steps
             number_of_steps += 1
@@ -387,21 +396,18 @@ class StableDiffusionDepth2ImgPipelineSlowTests(unittest.TestCase):
                 latents = latents.detach().cpu().numpy()
                 assert latents.shape == (1, 4, 60, 80)
                 latents_slice = latents[0, -3:, -3:, -1]
-                expected_slice = np.array([
-                    -1.148, -0.2147, -0.618, -2.48, -2.348, 0.3945, -2.05,
-                    -1.566, -1.52
-                ])
-                assert np.abs(latents_slice.flatten() - expected_slice).max(
-                ) < 0.1
+                expected_slice = np.array(
+                    [-1.1489, -0.2159, -0.6202, -2.4766, -2.3504, 0.3692, -2.0518, -1.5729, -1.5275]
+                )
+                assert np.abs(latents_slice.flatten() - expected_slice).max() < 0.1
 
         callback_fn.has_been_called = False
         pipe = StableDiffusionDepth2ImgPipeline.from_pretrained(
             "stabilityai/stable-diffusion-2-depth",
-            safety_checker=None,
-            paddle_dtype=paddle.float16)
+        )
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
-        inputs = self.get_inputs(dtype="float16")
+        inputs = self.get_inputs()
         pipe(**inputs, callback=callback_fn, callback_steps=1)
         assert callback_fn.has_been_called
         assert number_of_steps == 2
@@ -415,10 +421,10 @@ class StableDiffusionImg2ImgPipelineNightlyTests(unittest.TestCase):
         gc.collect()
         paddle.device.cuda.empty_cache()
 
-    def get_inputs(self, dtype="float32", seed=0):
+    def get_inputs(self, seed=0):
         generator = paddle.Generator().manual_seed(seed)
         init_image = load_image(
-            "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/depth2img/two_cats.png"
+            "https://bj.bcebos.com/v1/paddlenlp/datasets/hf-internal-testing/diffusers-images/resolve/main/depth2img/two_cats.png"
         )
         inputs = {
             "prompt": "two tigers",
@@ -427,7 +433,7 @@ class StableDiffusionImg2ImgPipelineNightlyTests(unittest.TestCase):
             "num_inference_steps": 3,
             "strength": 0.75,
             "guidance_scale": 7.5,
-            "output_type": "numpy",
+            "output_type": "np",
         }
         return inputs
 
