@@ -20,14 +20,15 @@ from ppdiffusers import (
     DEISMultistepScheduler,
     DPMSolverMultistepScheduler,
     DPMSolverSinglestepScheduler,
-    UniPCMultistepScheduler, )
+    UniPCMultistepScheduler,
+)
 
 from .test_schedulers import SchedulerCommonTest
 
 
 class DPMSolverSinglestepSchedulerTest(SchedulerCommonTest):
-    scheduler_classes = (DPMSolverSinglestepScheduler, )
-    forward_default_kwargs = (("num_inference_steps", 25), )
+    scheduler_classes = (DPMSolverSinglestepScheduler,)
+    forward_default_kwargs = (("num_inference_steps", 25),)
 
     def get_scheduler_config(self, **kwargs):
         config = {
@@ -41,6 +42,8 @@ class DPMSolverSinglestepSchedulerTest(SchedulerCommonTest):
             "sample_max_value": 1.0,
             "algorithm_type": "dpmsolver++",
             "solver_type": "midpoint",
+            "lambda_min_clipped": -float("inf"),
+            "variance_type": None,
         }
 
         config.update(**kwargs)
@@ -51,39 +54,28 @@ class DPMSolverSinglestepSchedulerTest(SchedulerCommonTest):
         num_inference_steps = kwargs.pop("num_inference_steps", None)
         sample = self.dummy_sample
         residual = 0.1 * sample
-        dummy_past_residuals = [
-            residual + 0.2, residual + 0.15, residual + 0.10
-        ]
+        dummy_past_residuals = [residual + 0.2, residual + 0.15, residual + 0.10]
 
         for scheduler_class in self.scheduler_classes:
             scheduler_config = self.get_scheduler_config(**config)
             scheduler = scheduler_class(**scheduler_config)
             scheduler.set_timesteps(num_inference_steps)
             # copy over dummy past residuals
-            scheduler.model_outputs = dummy_past_residuals[:scheduler.config.
-                                                           solver_order]
+            scheduler.model_outputs = dummy_past_residuals[: scheduler.config.solver_order]
 
             with tempfile.TemporaryDirectory() as tmpdirname:
                 scheduler.save_config(tmpdirname)
                 new_scheduler = scheduler_class.from_pretrained(tmpdirname)
                 new_scheduler.set_timesteps(num_inference_steps)
                 # copy over dummy past residuals
-                new_scheduler.model_outputs = dummy_past_residuals[:
-                                                                   new_scheduler.
-                                                                   config.
-                                                                   solver_order]
+                new_scheduler.model_outputs = dummy_past_residuals[: new_scheduler.config.solver_order]
 
             output, new_output = sample, sample
-            for t in range(time_step,
-                           time_step + scheduler.config.solver_order + 1):
-                output = scheduler.step(residual, t, output,
-                                        **kwargs).prev_sample
-                new_output = new_scheduler.step(residual, t, new_output,
-                                                **kwargs).prev_sample
+            for t in range(time_step, time_step + scheduler.config.solver_order + 1):
+                output = scheduler.step(residual, t, output, **kwargs).prev_sample
+                new_output = new_scheduler.step(residual, t, new_output, **kwargs).prev_sample
 
-                assert paddle.sum(paddle.abs(
-                    output -
-                    new_output)) < 1e-5, "Scheduler outputs are not identical"
+                assert paddle.sum(paddle.abs(output - new_output)) < 1e-5, "Scheduler outputs are not identical"
 
     def test_from_save_pretrained(self):
         pass
@@ -93,9 +85,7 @@ class DPMSolverSinglestepSchedulerTest(SchedulerCommonTest):
         num_inference_steps = kwargs.pop("num_inference_steps", None)
         sample = self.dummy_sample
         residual = 0.1 * sample
-        dummy_past_residuals = [
-            residual + 0.2, residual + 0.15, residual + 0.10
-        ]
+        dummy_past_residuals = [residual + 0.2, residual + 0.15, residual + 0.10]
 
         for scheduler_class in self.scheduler_classes:
             scheduler_config = self.get_scheduler_config()
@@ -103,8 +93,7 @@ class DPMSolverSinglestepSchedulerTest(SchedulerCommonTest):
             scheduler.set_timesteps(num_inference_steps)
 
             # copy over dummy past residuals (must be after setting timesteps)
-            scheduler.model_outputs = dummy_past_residuals[:scheduler.config.
-                                                           solver_order]
+            scheduler.model_outputs = dummy_past_residuals[: scheduler.config.solver_order]
 
             with tempfile.TemporaryDirectory() as tmpdirname:
                 scheduler.save_config(tmpdirname)
@@ -113,18 +102,12 @@ class DPMSolverSinglestepSchedulerTest(SchedulerCommonTest):
                 new_scheduler.set_timesteps(num_inference_steps)
 
                 # copy over dummy past residual (must be after setting timesteps)
-                new_scheduler.model_outputs = dummy_past_residuals[:
-                                                                   new_scheduler.
-                                                                   config.
-                                                                   solver_order]
+                new_scheduler.model_outputs = dummy_past_residuals[: new_scheduler.config.solver_order]
 
-            output = scheduler.step(residual, time_step, sample,
-                                    **kwargs).prev_sample
-            new_output = new_scheduler.step(residual, time_step, sample,
-                                            **kwargs).prev_sample
+            output = scheduler.step(residual, time_step, sample, **kwargs).prev_sample
+            new_output = new_scheduler.step(residual, time_step, sample, **kwargs).prev_sample
 
-            assert paddle.sum(paddle.abs(output - new_output)
-                              ) < 1e-5, "Scheduler outputs are not identical"
+            assert paddle.sum(paddle.abs(output - new_output)) < 1e-5, "Scheduler outputs are not identical"
 
     def full_loop(self, scheduler=None, **config):
         if scheduler is None:
@@ -147,6 +130,22 @@ class DPMSolverSinglestepSchedulerTest(SchedulerCommonTest):
 
         return sample
 
+    def test_full_uneven_loop(self):
+        scheduler = DPMSolverSinglestepScheduler(**self.get_scheduler_config())
+        num_inference_steps = 50
+        model = self.dummy_model()
+        sample = self.dummy_sample_deter
+        scheduler.set_timesteps(num_inference_steps)
+
+        # make sure that the first t is uneven
+        for i, t in enumerate(scheduler.timesteps[3:]):
+            residual = model(sample, t)
+            sample = scheduler.step(residual, t, sample).prev_sample
+
+        result_mean = paddle.mean(paddle.abs(sample))
+
+        assert abs(result_mean.item() - 0.2574) < 1e-3
+
     def test_timesteps(self):
         for timesteps in [25, 50, 100, 999, 1000]:
             self.check_over_configs(num_train_timesteps=timesteps)
@@ -182,7 +181,8 @@ class DPMSolverSinglestepSchedulerTest(SchedulerCommonTest):
                             sample_max_value=threshold,
                             algorithm_type="dpmsolver++",
                             solver_order=order,
-                            solver_type=solver_type, )
+                            solver_type=solver_type,
+                        )
 
     def test_prediction_type(self):
         for prediction_type in ["epsilon", "v_prediction"]:
@@ -197,23 +197,31 @@ class DPMSolverSinglestepSchedulerTest(SchedulerCommonTest):
                             solver_order=order,
                             solver_type=solver_type,
                             prediction_type=prediction_type,
-                            algorithm_type=algorithm_type, )
+                            algorithm_type=algorithm_type,
+                        )
                         sample = self.full_loop(
                             solver_order=order,
                             solver_type=solver_type,
                             prediction_type=prediction_type,
-                            algorithm_type=algorithm_type, )
-                        assert not paddle.isnan(sample).any(
-                        ), "Samples have nan numbers"
+                            algorithm_type=algorithm_type,
+                        )
+                        assert not paddle.isnan(sample).any(), "Samples have nan numbers"
 
     def test_lower_order_final(self):
         self.check_over_configs(lower_order_final=True)
         self.check_over_configs(lower_order_final=False)
 
+    def test_lambda_min_clipped(self):
+        self.check_over_configs(lambda_min_clipped=-float("inf"))
+        self.check_over_configs(lambda_min_clipped=-5.1)
+
+    def test_variance_type(self):
+        self.check_over_configs(variance_type=None)
+        self.check_over_configs(variance_type="learned_range")
+
     def test_inference_steps(self):
         for num_inference_steps in [1, 2, 3, 5, 10, 50, 100, 999, 1000]:
-            self.check_over_forward(
-                num_inference_steps=num_inference_steps, time_step=0)
+            self.check_over_forward(num_inference_steps=num_inference_steps, time_step=0)
 
     def test_full_loop_no_noise(self):
         sample = self.full_loop()
@@ -221,16 +229,27 @@ class DPMSolverSinglestepSchedulerTest(SchedulerCommonTest):
 
         assert abs(result_mean.item() - 0.2791) < 1e-3
 
+    def test_full_loop_with_karras(self):
+        sample = self.full_loop(use_karras_sigmas=True)
+        result_mean = paddle.mean(paddle.abs(sample))
+
+        assert abs(result_mean.item() - 0.2248) < 1e-3
+
     def test_full_loop_with_v_prediction(self):
         sample = self.full_loop(prediction_type="v_prediction")
         result_mean = paddle.mean(paddle.abs(sample))
 
         assert abs(result_mean.item() - 0.1453) < 1e-3
 
+    def test_full_loop_with_karras_and_v_prediction(self):
+        sample = self.full_loop(prediction_type="v_prediction", use_karras_sigmas=True)
+        result_mean = paddle.mean(paddle.abs(sample))
+
+        assert abs(result_mean.item() - 0.0649) < 1e-3
+
     def test_fp16_support(self):
         scheduler_class = self.scheduler_classes[0]
-        scheduler_config = self.get_scheduler_config(
-            thresholding=True, dynamic_thresholding_ratio=0)
+        scheduler_config = self.get_scheduler_config(thresholding=True, dynamic_thresholding_ratio=0)
         scheduler = scheduler_class(**scheduler_config)
 
         num_inference_steps = 10
