@@ -20,7 +20,7 @@ from .test_schedulers import SchedulerCommonTest
 
 
 class HeunDiscreteSchedulerTest(SchedulerCommonTest):
-    scheduler_classes = (HeunDiscreteScheduler, )
+    scheduler_classes = (HeunDiscreteScheduler,)
     num_inference_steps = 10
 
     def get_scheduler_config(self, **kwargs):
@@ -39,16 +39,15 @@ class HeunDiscreteSchedulerTest(SchedulerCommonTest):
             self.check_over_configs(num_train_timesteps=timesteps)
 
     def test_betas(self):
-        for beta_start, beta_end in zip([0.00001, 0.0001, 0.001],
-                                        [0.0002, 0.002, 0.02]):
+        for beta_start, beta_end in zip([0.00001, 0.0001, 0.001], [0.0002, 0.002, 0.02]):
             self.check_over_configs(beta_start=beta_start, beta_end=beta_end)
 
     def test_schedules(self):
-        for schedule in ["linear", "scaled_linear"]:
+        for schedule in ["linear", "scaled_linear", "exp"]:
             self.check_over_configs(beta_schedule=schedule)
 
     def test_prediction_type(self):
-        for prediction_type in ["epsilon", "v_prediction"]:
+        for prediction_type in ["epsilon", "v_prediction", "sample"]:
             self.check_over_configs(prediction_type=prediction_type)
 
     def test_full_loop_no_noise(self):
@@ -78,8 +77,7 @@ class HeunDiscreteSchedulerTest(SchedulerCommonTest):
 
     def test_full_loop_with_v_prediction(self):
         scheduler_class = self.scheduler_classes[0]
-        scheduler_config = self.get_scheduler_config(
-            prediction_type="v_prediction")
+        scheduler_config = self.get_scheduler_config(prediction_type="v_prediction")
         scheduler = scheduler_class(**scheduler_config)
 
         scheduler.set_timesteps(self.num_inference_steps)
